export declare type Direction = "W" | "E" | "S" | "N";
/**
 * Represents a DMS position
 * @memberof module:dms
 */
export declare class Dms {
    dd: number;
    hemisphere: Direction;
    constructor(dd: number, longOrLat: string);
    /**
     * Returns the DMS parts as an array.
     * The first three elements of the returned array are numbers:
     * degrees, minutes, and seconds respectively. The fourth
     * element is a string indicating the hemisphere: "N", "S", "E", or "W".
     * @returns {Array.<(number|string)>}
     */
    getDmsArray(): [number, number, number, Direction];
    /**
     * Returns the DMS value as a string.
     */
    toString(): string;
}
/**
 * Represents DMS coordinates.
 * @alias module:dms
 */
export default class DmsCoordinates {
    private lat;
    private lon;
    /**
     * A regular expression matching DMS coordinate.
     * Example matches:
     * E.g., ["40:26:46.302N", "40", "26", "46.302", "N"]
     * E.g., ["40.446195N", "40.446195", undefined, undefined, "N"]
     * @type {RegExp}
     * @static
     */
    static dmsRe: RegExp;
    private _longitude;
    private _latitude;
    /**
     * Longitude
     * @member {Dms} longitude - Longitude (X coordinate);
     */
    longitude: Dms;
    /**
     * Latitude
     * @member {Dms} longitude - Latitude (y coordinate);
     */
    latitude: Dms;
    /**
     * Represents a location on the earth in WGS 1984 coordinates.
     * @constructor
     * @param {number} latitude - WGS 84 Y coordinates
     * @param {number} longitude - WGS 84 X coordinates
     * @throws {TypeError} - latitude and longitude must be numbers.
     * @throws {RangeError} - latitude must be between -180 and 180, and longitude between -90 and 90. Neither can be NaN.
     */
    constructor(lat: number, lon: number);
    /**
     * @typedef {Object} DmsArrays
     * @property {Array.<(number|string)>} longitude
     * @property {Array.<(number|string)>} latitude
     */
    /**
     * Returns an object containing arrays containing degree / minute / second components.
     * @returns {DmsArrays}
     */
    getDmsArrays(): {
        longitude: [number, number, number, "W" | "E" | "S" | "N"];
        latitude: [number, number, number, "W" | "E" | "S" | "N"];
    };
    /**
     * Returns the coordinates to a comma-separated string.
     * @returns {string}
     */
    toString(): string;
    /** Parses a Degrees Minutes Seconds string into a Decimal Degrees number.
     * @param {string} dmsStr A string containing a coordinate in either DMS or DD format.
     * @return {Number} If dmsStr is a valid coordinate string, the value in decimal degrees will be returned. Otherwise NaN will be returned.
     */
    static parseDms(dmsStr: string): number;
}
